@@ -1,7 +1,7 @@
 /**
  * Contains basic inheritance mechanism
  *
- *  Copyright (C) 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
+ *  Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
  *
  *  This file is part of GNU ease.js.
  *
@@ -34,6 +34,7 @@ var _console = ( typeof console !== 'undefined' ) ? console : undefined;
 
 var util         = require( './util' ),
     ClassBuilder = require( './ClassBuilder' ),
+    Interface    = require( './interface' ),
 
     warn        = require( './warn' ),
     Warning     = warn.Warning,
@@ -179,11 +180,6 @@ module.exports.isClass = function( obj )
 {
     obj = obj || _dummyclass;
 
-    if ( !obj.prototype )
-    {
-        return false;
-    }
-
     var meta = ClassBuilder.getMeta( obj );
 
     // TODO: we're checking a random field on the meta object; do something
@@ -477,6 +473,11 @@ function createImplement( base, ifaces, cname )
  * be explicit: in this case, any instantiation attempts will result in an
  * exception being thrown.
  *
+ * This staging object may be used as a base for extending.  Note, however,
+ * that its metadata are unavailable at the time of definition---its
+ * contents are marked as "lazy" and must be processed using the mixin's
+ * eventual metadata.
+ *
  * @param  {function()}        basef    returns base from which to lazily
  *                                       extend
  * @param  {Array.<Function>}  traits   traits to mix in
@@ -491,6 +492,13 @@ function createUse( basef, traits, nonbase )
     // invoking the partially applied class will immediately complete its
     // definition and instantiate it with the provided constructor arguments
     var partial = function()
+    {
+        return partialClass()
+            .apply( null, arguments );
+    };
+
+
+    var partialClass = function()
     {
         // this argument will be set only in the case where an existing
         // (non-base) class is extended, meaning that an explict Class or
@@ -503,8 +511,7 @@ function createUse( basef, traits, nonbase )
             );
         }
 
-        return createMixedClass( basef(), traits )
-            .apply( null, arguments );
+        return createMixedClass( basef(), traits );
     };
 
 
@@ -550,6 +557,20 @@ function createUse( basef, traits, nonbase )
         return partial.extend( {} );
     };
 
+    partial.asPrototype = function()
+    {
+        return partialClass().asPrototype();
+    };
+
+    partial.__isInstanceOf = Interface.isInstanceOf;
+
+    // allow the system to recognize this object as a viable base for
+    // extending, but mark the metadata as lazy: since we defer all
+    // processing for mixins, we cannot yet know all metadata
+    // TODO: `_lazy' is a kluge
+    ClassBuilder.masquerade( partial );
+    ClassBuilder.getMeta( partial )._lazy = true;
+
     return partial;
 }
 
