@@ -24,18 +24,36 @@
  * @type {Object.<string,boolean>}
  */
 var _keywords = {
-    'public':    true,
-    'protected': true,
-    'private':   true,
-    'static':    true,
-    'abstract':  true,
-    'const':     true,
-    'virtual':   true,
-    'override':  true,
-    'proxy':     true,
-    'weak':      true,
+    'public':    1,
+    'protected': 1<<1,
+    'private':   1<<2,
+    'static':    1<<3,
+    'abstract':  1<<4,
+    'const':     1<<5,
+    'virtual':   1<<6,
+    'override':  1<<7,
+    'proxy':     1<<8,
+    'weak':      1<<9,
 };
 
+/**
+ * Keyword masks for conveniently checking the keyword bitfield
+ * @type {Object.<string,integer>}
+ */
+var _kmasks = {
+    amods: _keywords[ 'public' ]
+        | _keywords[ 'protected' ]
+        | _keywords[ 'private' ],
+
+    'virtual': _keywords[ 'abstract' ]
+        | _keywords[ 'virtual' ],
+};
+
+
+// expose magic values
+exports.kvals  = _keywords;
+exports.kmasks = _kmasks;
+
 
 /**
  * Parses property keywords
@@ -48,6 +66,7 @@ exports.parseKeywords = function ( prop )
 {
     var name        = prop,
         keywords    = [],
+        bitwords    = 0x00,
         keyword_obj = {};
 
     prop = ''+( prop );
@@ -58,27 +77,41 @@ exports.parseKeywords = function ( prop )
     {
         name = keywords.pop();
 
-        var i       = keywords.length,
-            keyword = '';
-
+        var i = keywords.length;
         while ( i-- )
         {
-            keyword = keywords[ i ];
+            var keyword = keywords[ i ],
+                kval    = _keywords[ keyword ];
 
             // ensure the keyword is recognized
-            if ( !_keywords[ keyword ] )
+            if ( !kval )
             {
                 throw Error(
                     "Unexpected keyword for '" + name + "': " + keyword
                 );
             }
 
+            // ease-of-access
             keyword_obj[ keyword ] = true;
+
+            // permits quick and concise checks
+            bitwords |= kval;
         }
     }
 
+    // members with an underscore prefix are implicitly private, unless an
+    // access modifier is explicitly provided; double-underscore is ingored,
+    // as they denote special members that do not become part of the
+    // prototype and are reserved by ease.js
+    if ( ( name.match( /^_[^_]/ ) && !( bitwords & _kmasks.amods ) ) )
+    {
+        keyword_obj[ 'private' ] = true;
+        bitwords |= _keywords[ 'private' ];
+    }
+
     return {
         name:     name,
         keywords: keyword_obj,
+        bitwords: bitwords,
     };
 }
