@@ -23,8 +23,6 @@ require( 'common' ).testCase(
 {
     caseSetUp: function()
     {
-        // XXX: get rid of this disgusting mess; we're mid-refactor and all
-        // these dependencies should not be necessary for testing
         this.Sut =  this.require( 'ClassBuilder' );
         this.MethodWrapperFactory = this.require( 'MethodWrapperFactory' );
 
@@ -34,14 +32,17 @@ require( 'common' ).testCase(
 
     setUp: function()
     {
+        // XXX: get rid of this disgusting mess; we're mid-refactor and all
+        // these dependencies should not be necessary for testing
         this.builder = this.Sut(
-            this.require( '/MemberBuilder' )(
+            this.require( 'warn' ).DismissiveHandler(),
+            this.require( 'MemberBuilder' )(
                 this.MethodWrapperFactory( this.wrappers.wrapNew ),
                 this.MethodWrapperFactory( this.wrappers.wrapOverride ),
                 this.MethodWrapperFactory( this.wrappers.wrapProxy ),
                 this.getMock( 'MemberBuilderValidator' )
             ),
-            this.require( '/VisibilityObjectFactoryFactory' )
+            this.require( 'VisibilityObjectFactoryFactory' )
                 .fromEnvironment()
         )
     },
